
SSAM (Spot-based Spatial cell-type Analysis by Multidimensional mRNA density estimation)
========================================================================================

Author: Jeongbin Park (jeongbin.park@charite.de)\ :sup:`1,2` and Wonyl Choi (wonyl@bu.edu)\ :sup:`3`

:sup:`1`\ Digital Health Center, Berlin Institute of Health (BIH) and Charité – Universitätsmedizin, Berlin, Germany; :sup:`2`\ Faculty of Biosciences, Heidelberg University, Heidelberg, Germany; :sup:`3`\ Department of Computer Science, Boston University, Boston, the United States of America

(Not referring this :laughing:: https://en.wikipedia.org/wiki/Ssam)

This project was done under supervision of Dr. Naveed Ishaque (naveed.ishaque@charite.de) and Prof. Roland Eils (roland.eils@charite.de), and in collaboration with the SpaceTx consortium and the Human Cell Atlas project.

Please also check our example Jupyter notebooks here: https://github.com/eilslabs/ssam_example

Prerequisites
=============

Currently SSAM was only tested with Python 3 in Linux environment. In addition to this package, SSAM requires a local R installation with pre-installed packages ``feather`` and ``sctransform``. For details, please follow the instructions here: https://ssam.readthedocs.io/en/release/userguide/01-tldr.html#installation

Install
=======

https://ssam.readthedocs.io/en/release/userguide/01-tldr.html#installation

Documentation
=============

https://ssam.readthedocs.io/

Citations
=========

J Park, W Choi, S Tiesmeyer, B Long, LE Borm, E Garren, TN Nguyen, S Codeluppi, M Schlesner, B Tasic, R Eils, N Ishaque. "Segmentation-free inference of cell types from in situ transcriptomics data." *bioRxiv* **800748**. doi: https://doi.org/10.1101/800748

License
=======

Copyright (C) 2018 Jeongbin Park and Wonyl Choi

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published
by the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see https://www.gnu.org/licenses/.
